@@ -39,6 +39,8 @@ import serial
 import serial.serialutil
 import serial.tools.list_ports as port_list
 
+import click
+
 CMD_SUCCESS = 0
 INVALID_COMMAND = 1
 SRC_ADDR_ERROR = 2
@@ -1620,6 +1622,7 @@ def signal_handler(sig, frame):
     logging.error('Ctrl+C Pressed bailing out!')
     sys.exit(0)
 
+@click.command()
 def main(argv=None):
     global prog
 
